Authors
=======
* Michael van Tellingen

Contributors
============
* vashek
* Marco Vellinga
* jaceksnet
* Andrew Serong
* Joeri Bekker
* Eric Wong
* Jacek Stępniewski
* Alexey Stepanov
* Julien Delasoie
* bjarnagin
* mcordes
* Sam Denton
* David Baumgold
* fiebiga
* Antonio Cuni
* Alexandre de Mari
* Jason Vertrees
* Nicolas Evrard
* Matt Grimm (mgrimm)
* Marek Wywiał
* Falldog
* btmanm
* Caleb Salt
* Julien Marechal
* Mike Fiedler
* Dave Wapstra
* OrangGeeGee
* Stefano Parmesan
* Jan Murre
* Ben Tucker
* Bruno Duyé
* Christoph Heuel
* Derek Harland
* Eric Waller
* Falk Schuetzenmeister
* Jon Jenkins
* Raymond Piller
* Zoltan Benedek
* Øyvind Heddeland Instefjord
